@@ -135,7 +135,7 @@ class ShapleyLorenzShare:
             specifies, whether to plot a seperate graph for the
             class tuple, in case of multiple classes
         '''
-        lz_sorted = LZ[np.argsort(LZ[:,1])]
+        lz_sorted = self.LZ_shares[np.argsort(self.LZ_shares[:,1])]
         if tuple == False:
             plt.bar(lz_sorted[:,0], lz_sorted[:,1], color = (0.0,0.36,0.8,0.8))
             plt.title('Shapley Lorenz Zonoid Values', fontsize = '15')
@@ -200,10 +200,10 @@ class ShapleyLorenzShare:
             self.y_mu = np.mean(self.y_bg)
 
         #Container for output
-        LZ = np.zeros((self.M, 1)) # in regression case or if 'predict' specified in classification case
+        self.LZ = np.zeros((self.M, 1)) # in regression case or if 'predict' specified in classification case
         if pred_out == 'predict_proba':
-            LZ0 = np.zeros((self.M,1))
-            LZ1 = np.zeros((self.M,1))
+            self.LZ0 = np.zeros((self.M,1))
+            self.LZ1 = np.zeros((self.M,1))
 
         #Loop over all covariates
         for k in tqdm(range(self.M)):
@@ -360,7 +360,7 @@ class ShapleyLorenzShare:
                 Lor_val = ((2/(self.N_test**2))*self.y_mu)*Lor_val_temp_sum
                 Lor_val = Lor_val.reshape((1,2**(self.M-1)))
 
-                LZ[k,0] = np.dot(Lor_val,kernel) # equation 19 on page 10 of Giudiuci and Raffinetti (Feb 2020) paper
+                self.LZ[k,0] = np.dot(Lor_val,kernel) # equation 19 on page 10 of Giudiuci and Raffinetti (Feb 2020) paper
 
             elif class_prob == True and (pred_out == 'predict_proba' or pred_out == 'predict_log_proba'):
                 for j in range(self.N_test):
@@ -377,14 +377,16 @@ class ShapleyLorenzShare:
                 Lor_val0 = Lor_val0.reshape((1,2**(self.M-1)))
                 Lor_val1 = Lor_val1.reshape((1,2**(self.M-1)))
 
-                LZ0[k,0] = np.dot(Lor_val0,kernel)
-                LZ1[k,0] = np.dot(Lor_val1,kernel)
+                self.LZ0[k,0] = np.dot(Lor_val0,kernel)
+                self.LZ1[k,0] = np.dot(Lor_val1,kernel)
 
         if class_prob == False or (class_prob == True and pred_out == 'predict'):
-            return np.column_stack((X.col_names,LZ))
+            self.LZ_shares = np.column_stack((X.col_names,self.LZ))
+            return self.LZ_shares
 
         elif class_prob == True and (pred_out == 'predict_proba' or pred_out == 'predict_log_proba'):
-            return np.column_stack((X.col_names,LZ0)), np.column_stack((X.col_names, LZ1));
+            self.LZ_shares = [np.column_stack((X.col_names,self.LZ0)), np.column_stack((X.col_names, self.LZ1))]
+            return np.column_stack((X.col_names,self.LZ0)), np.column_stack((X.col_names, self.LZ1));
 
 
 #Auxiliary functions
